@@ -1,4 +1,4 @@
-/*      $Id: client.h 27356 2008-07-20 21:22:15Z olivier $
+/*      $Id: client.h 28585 2008-11-02 17:45:46Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -102,7 +102,15 @@
 #endif
 
 #ifndef CLIENT_BLINK_TIMEOUT
-#define CLIENT_BLINK_TIMEOUT            500 /* ms */
+#define CLIENT_BLINK_TIMEOUT            500  /* ms */
+#endif
+
+#ifndef CLIENT_PING_TIMEOUT
+#define CLIENT_PING_TIMEOUT             3000 /* ms */
+#endif
+
+#ifndef MAX_BLINK_ITERATIONS
+#define MAX_BLINK_ITERATIONS            5
 #endif
 
 #define XFWM_FLAG_HAS_BORDER            (1L<<0)
@@ -155,6 +163,7 @@
 #define WM_FLAG_TAKEFOCUS               (1L<<2)
 #define WM_FLAG_CONTEXT_HELP            (1L<<3)
 #define WM_FLAG_URGENT                  (1L<<4)
+#define WM_FLAG_PING                    (1L<<5)
 
 #define XFWM_FLAG_INITIAL_VALUES        XFWM_FLAG_HAS_BORDER | \
                                         XFWM_FLAG_HAS_MENU | \
@@ -211,9 +220,6 @@
                                                                           XFWM_FLAG_LEGACY_FULLSCREEN) && \
                                          !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN | CLIENT_FLAG_MAXIMIZED))
 
-#define CLIENT_CAN_STICK_WINDOW(c)      (!(c->transient_for) && \
-                                         FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_STICK))
-
 typedef enum
 {
     UNSET = 0,
@@ -281,19 +287,29 @@ struct _Client
     int previous_height;
     int initial_layer;
     int ncmap;
+    int blink_iterations;
     int button_status[BUTTON_COUNT];
     int struts[STRUTS_SIZE];
+    gchar *hostname;
     gchar *name;
-    Time user_time;
+    guint32 user_time;
+    GPid pid;
+    guint32 ping_time;
     unsigned long flags;
     unsigned long wm_flags;
     unsigned long xfwm_flags;
+
+    /* Termination dialog */
+    int dialog_pid;
+    int dialog_fd;
     /* Timout for asynchronous icon update */
     guint icon_timeout_id;
     /* Timout for asynchronous frame update */
     guint frame_timeout_id;
     /* Timout to manage blinking decorations for urgent windows */
     guint blink_timeout_id;
+    /* Timout for asynchronous icon update */
+    guint ping_timeout_id;
     /* Opacity for the compositor */
     guint opacity;
     guint opacity_applied;
@@ -325,16 +341,21 @@ void                     clientAddUserTimeWin                   (Client *);
 void                     clientRemoveUserTimeWin                (Client *);
 void                     clientUpdateUrgency                    (Client *);
 void                     clientCoordGravitate                   (Client *,
+                                                                 int,
                                                                  int,
                                                                  int *,
                                                                  int *);
 void                     clientAdjustCoordGravity               (Client *,
+                                                                 int,
                                                                  unsigned long *,
                                                                  XWindowChanges *);
 void                     clientConfigure                        (Client *,
                                                                  XWindowChanges *,
                                                                  unsigned long,
                                                                  unsigned short);
+void                     clientMoveResizeWindow                 (Client *,
+                                                                 XWindowChanges *,
+                                                                 unsigned long);
 void                     clientGetMWMHints                      (Client *,
                                                                  gboolean);
 void                     clientGetWMNormalHints                 (Client *,
@@ -360,17 +381,18 @@ Client                  *clientGetFromWindow                    (Client *,
                                                                  unsigned short);
 void                     clientShow                             (Client *,
                                                                  gboolean);
-void                     clientHide                             (Client *,
+void                     clientWithdraw                         (Client *,
                                                                  int,
                                                                  gboolean);
-void                     clientHideAll                          (Client *,
+void                     clientWithdrawAll                      (Client *,
                                                                  int);
 void                     clientClearAllShowDesktop              (ScreenInfo *);
 void                     clientToggleShowDesktop                (ScreenInfo *);
 void                     clientActivate                         (Client *,
-                                                                 Time);
+                                                                 guint32);
 void                     clientClose                            (Client *);
 void                     clientKill                             (Client *);
+void                     clientTerminate                        (Client *);
 void                     clientEnterContextMenuState            (Client *);
 void                     clientSetLayer                         (Client *,
                                                                  int);
