@@ -1,4 +1,4 @@
-/*      $Id: display.c 27356 2008-07-20 21:22:15Z olivier $
+/*      $Id: display.c 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -90,6 +90,7 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_NET_DESKTOP_NAMES",
         "_NET_DESKTOP_VIEWPORT",
         "_NET_FRAME_EXTENTS",
+        "_NET_MOVERESIZE_WINDOW",
         "_NET_NUMBER_OF_DESKTOPS",
         "_NET_REQUEST_FRAME_EXTENTS",
         "_NET_SHOWING_DESKTOP",
@@ -117,6 +118,8 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_NET_WM_ICON_NAME",
         "_NET_WM_MOVERESIZE",
         "_NET_WM_NAME",
+        "_NET_WM_PID",
+        "_NET_WM_PING",
         "_NET_WM_WINDOW_OPACITY",
         "_NET_WM_WINDOW_OPACITY_LOCKED",
         "_NET_WM_STATE",
@@ -671,85 +674,85 @@ myDisplayGetDefaultScreen (DisplayInfo *display)
     return NULL;
 }
 
-Time
+guint32
 myDisplayUpdateCurrentTime (DisplayInfo *display, XEvent *ev)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
     switch (ev->type)
     {
         case KeyPress:
         case KeyRelease:
-            display->current_time = (Time) ev->xkey.time;
+            display->current_time = (guint32) ev->xkey.time;
             break;
         case ButtonPress:
         case ButtonRelease:
-            display->current_time = (Time) ev->xbutton.time;
+            display->current_time = (guint32) ev->xbutton.time;
             break;
         case MotionNotify:
-            display->current_time = (Time) ev->xmotion.time;
+            display->current_time = (guint32) ev->xmotion.time;
             break;
         case EnterNotify:
         case LeaveNotify:
-            display->current_time = (Time) ev->xcrossing.time;
+            display->current_time = (guint32) ev->xcrossing.time;
             break;
         case PropertyNotify:
-            display->current_time = (Time) ev->xproperty.time;
+            display->current_time = (guint32) ev->xproperty.time;
             break;
         case SelectionClear:
-            display->current_time = (Time) ev->xselectionclear.time;
+            display->current_time = (guint32) ev->xselectionclear.time;
             break;
         case SelectionRequest:
-            display->current_time = (Time) ev->xselectionrequest.time;
+            display->current_time = (guint32) ev->xselectionrequest.time;
             break;
         case SelectionNotify:
-            display->current_time = (Time) ev->xselection.time;
+            display->current_time = (guint32) ev->xselection.time;
             break;
         default:
-            display->current_time = (Time) CurrentTime;
+            display->current_time = (guint32) CurrentTime;
             break;
     }
     return display->current_time;
 }
 
-Time
+guint32
 myDisplayGetCurrentTime (DisplayInfo *display)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
-    TRACE ("myDisplayGetCurrentTime gives timestamp=%u", (unsigned int) display->current_time);
-    return (Time) display->current_time;
+    TRACE ("myDisplayGetCurrentTime gives timestamp=%u", (guint32) display->current_time);
+    return display->current_time;
 }
 
-Time
-myDisplayGetTime (DisplayInfo * display, Time timestamp)
+guint32
+myDisplayGetTime (DisplayInfo * display, guint32 timestamp)
 {
-    Time time;
+    guint32 time;
 
     time = timestamp;
-    if (time == (Time) CurrentTime)
+    if (time == (guint32) CurrentTime)
     {
         time = getXServerTime (display);
     }
 
-    TRACE ("myDisplayGetTime gives timestamp=%u", (unsigned int) time);
-    return (time);
+    TRACE ("myDisplayGetTime gives timestamp=%u", (guint32) time);
+    return time;
 }
 
-Time
+guint32
 myDisplayGetLastUserTime (DisplayInfo *display)
 {
-    g_return_val_if_fail (display != NULL, (Time) CurrentTime);
+    g_return_val_if_fail (display != NULL, CurrentTime);
 
-    TRACE ("myDisplayGetLastUserTime gives timestamp=%u", (unsigned int) display->last_user_time);
-    return (Time) display->last_user_time;
+    TRACE ("myDisplayGetLastUserTime gives timestamp=%u", (guint32) display->last_user_time);
+    return display->last_user_time;
 }
 
 void
-myDisplaySetLastUserTime (DisplayInfo *display, Time timestamp)
+myDisplaySetLastUserTime (DisplayInfo *display, guint32 timestamp)
 {
     g_return_if_fail (display != NULL);
-    g_return_if_fail (timestamp != (Time) 0);
+    g_return_if_fail (timestamp != 0);
 
     if (TIMESTAMP_IS_BEFORE(timestamp, display->last_user_time))
     {
@@ -759,10 +762,10 @@ myDisplaySetLastUserTime (DisplayInfo *display, Time timestamp)
 }
 
 void
-myDisplayUpdateLastUserTime (DisplayInfo *display, Time timestamp)
+myDisplayUpdateLastUserTime (DisplayInfo *display, guint32 timestamp)
 {
     g_return_if_fail (display != NULL);
-    g_return_if_fail (timestamp != (Time) 0);
+    g_return_if_fail (timestamp != 0);
 
     if (TIMESTAMP_IS_BEFORE(display->last_user_time, timestamp))
     {
