@@ -1,4 +1,4 @@
-/*      $Id: events.c 27477 2008-08-17 20:05:59Z stephan $
+/*      $Id: events.c 28680 2008-11-09 11:46:07Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -77,13 +77,6 @@
                                  ButtonPressMask | \
                                  ButtonReleaseMask)
 
-#define MODIFIER_MASK           (ShiftMask | \
-                                 ControlMask | \
-                                 AltMask | \
-                                 MetaMask | \
-                                 SuperMask | \
-                                 HyperMask)
-
 static GdkAtom atom_rcfiles = GDK_NONE;
 static xfwmWindow menu_event_window;
 static int edge_scroll_x = 0;
@@ -262,7 +255,7 @@ typeOfClick (ScreenInfo *screen_info, Window w, XEvent * ev, gboolean allow_doub
 static gboolean
 check_button_time (XButtonEvent *ev)
 {
-    static Time last_button_time = (Time) CurrentTime;
+    static guint32 last_button_time = CurrentTime;
 
     if (last_button_time > ev->time)
     {
@@ -291,24 +284,6 @@ handleMotionNotify (DisplayInfo *display_info, XMotionEvent * ev)
     return EVENT_FILTER_REMOVE;
 }
 
-static int
-getKeyPressed (ScreenInfo *screen_info, XKeyEvent * ev)
-{
-    int key, state;
-
-    state = ev->state & MODIFIER_MASK;
-    for (key = 0; key < KEY_COUNT; key++)
-    {
-        if ((screen_info->params->keys[key].keycode == ev->keycode)
-            && (screen_info->params->keys[key].modifier == state))
-        {
-            break;
-        }
-    }
-
-    return key;
-}
-
 static eventFilterStatus
 handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
 {
@@ -334,7 +309,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
     if (c)
     {
         screen_info = c->screen_info;
-        key = getKeyPressed (screen_info, ev);
+        key = myScreenGetKeyPressed (screen_info, ev);
         status = EVENT_FILTER_REMOVE;
 
         switch (key)
@@ -346,6 +321,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 clientResize (c, CORNER_BOTTOM_RIGHT, (XEvent *) ev);
                 break;
             case KEY_CYCLE_WINDOWS:
+            case KEY_CYCLE_REVERSE_WINDOWS:
                 clientCycle (c, ev);
                 break;
             case KEY_CLOSE_WINDOW:
@@ -354,7 +330,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
             case KEY_HIDE_WINDOW:
                 if (CLIENT_CAN_HIDE_WINDOW (c))
                 {
-                    clientHide (c, c->win_workspace, TRUE);
+                    clientWithdraw (c, c->win_workspace, TRUE);
                 }
                 break;
             case KEY_MAXIMIZE_WINDOW:
@@ -370,7 +346,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
                 clientToggleShaded (c);
                 break;
             case KEY_STICK_WINDOW:
-                if (CLIENT_CAN_STICK_WINDOW(c))
+                if (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_STICK))
                 {
                     clientToggleSticky (c, TRUE);
                     frameQueueDraw (c, FALSE);
@@ -445,7 +421,7 @@ handleKeyPress (DisplayInfo *display_info, XKeyEvent * ev)
     }
     else
     {
-        key = getKeyPressed (ev_screen_info, ev);
+        key = myScreenGetKeyPressed (ev_screen_info, ev);
         switch (key)
         {
             case KEY_CYCLE_WINDOWS:
@@ -710,7 +686,7 @@ button1Action (Client * c, XButtonEvent * ev)
             case DBL_CLICK_ACTION_HIDE:
                 if (CLIENT_CAN_HIDE_WINDOW (c))
                 {
-                    clientHide (c, c->win_workspace, TRUE);
+                    clientWithdraw (c, c->win_workspace, TRUE);
                 }
                 break;
             default:
@@ -779,9 +755,7 @@ titleButton (Client * c, int state, XButtonEvent * ev)
     }
     else if (ev->button == Button4)
     {
-
         /* Mouse wheel scroll up */
-
         if (state == AltMask)
         {
             clientIncOpacity(c);
@@ -794,7 +768,6 @@ titleButton (Client * c, int state, XButtonEvent * ev)
     else if (ev->button == Button5)
     {
         /* Mouse wheel scroll down */
-
         if (state == AltMask)
         {
             clientDecOpacity(c);
@@ -819,7 +792,7 @@ titleButton (Client * c, int state, XButtonEvent * ev)
 static void
 rootScrollButton (DisplayInfo *display_info, XButtonEvent * ev)
 {
-    static Time lastscroll = (Time) CurrentTime;
+    static guint32 lastscroll = CurrentTime;
     ScreenInfo *screen_info;
 
     if ((ev->time - lastscroll) < 25)  /* ms */
@@ -1250,7 +1223,7 @@ handleConfigureNotify (DisplayInfo *display_info, XConfigureEvent * ev)
 static eventFilterStatus
 handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
 {
-    Client *c = NULL;
+    Client *c;
     XWindowChanges wc;
 
     TRACE ("entering handleConfigureRequest");
@@ -1296,105 +1269,14 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
     }
     if (c)
     {
-        gboolean constrained = FALSE;
-        ScreenInfo *screen_info = c->screen_info;
-
         TRACE ("handleConfigureRequest managed window \"%s\" (0x%lx)", c->name, c->window);
         if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MOVING_RESIZING))
         {
             /* Sorry, but it's not the right time for configure request */
             return EVENT_FILTER_REMOVE;
         }
-        if (c->type == WINDOW_DESKTOP)
-        {
-            /* Ignore stacking request for DESKTOP windows */
-            ev->value_mask &= ~(CWSibling | CWStackMode);
-        }
-        clientAdjustCoordGravity (c, &ev->value_mask, &wc);
-
-        if (FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
-        {
-            GdkRectangle rect;
-            gint monitor_nbr;
-            int cx, cy;
-
-            /* size request from fullscreen windows get fullscreen */
-
-            cx = frameX (c) + (frameWidth (c) / 2);
-            cy = frameY (c) + (frameHeight (c) / 2);
-
-            monitor_nbr = find_monitor_at_point (screen_info->gscr, cx, cy);
-            gdk_screen_get_monitor_geometry (screen_info->gscr, monitor_nbr, &rect);
-
-            wc.x = rect.x;
-            wc.y = rect.y;
-            wc.width = rect.width;
-            wc.height = rect.height;
-
-            ev->value_mask |= (CWX | CWY | CWWidth | CWHeight);
-        }
-        else if (FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED)
-                 && (screen_info->params->borderless_maximize))
-        {
-            wc.x = c->x;
-            wc.y = c->y;
-            wc.width = c->width;
-            wc.height = c->height;
-        }
-        /* Clean up buggy requests that set all flags */
-        if ((ev->value_mask & CWX) && (wc.x == c->x))
-        {
-            ev->value_mask &= ~CWX;
-        }
-        if ((ev->value_mask & CWY) && (wc.y == c->y))
-        {
-            ev->value_mask &= ~CWY;
-        }
-        if ((ev->value_mask & CWWidth) && (wc.width == c->width))
-        {
-            ev->value_mask &= ~CWWidth;
-        }
-        if ((ev->value_mask & CWHeight) && (wc.height == c->height))
-        {
-            ev->value_mask &= ~CWHeight;
-        }
-        /* Still a move/resize after cleanup? */
-        if (ev->value_mask & (CWX | CWY | CWWidth | CWHeight))
-        {
-            if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
-            {
-                clientRemoveMaximizeFlag (c);
-            }
-            constrained = TRUE;
-        }
-
-        /*
-           Let's say that if the client performs a XRaiseWindow, we show the window if focus
-           stealing prevention is not activated, otherwise we just set the "demands attention"
-           flag...
-         */
-        if ((ev->value_mask & CWStackMode) && (wc.stack_mode == Above) && (wc.sibling == None) && !(c->type & WINDOW_TYPE_DONT_FOCUS))
-        {
-            Client *last_raised;
-
-            last_raised = clientGetLastRaise (screen_info);
-            if (last_raised && (c != last_raised))
-            {
-                if ((screen_info->params->prevent_focus_stealing) && (screen_info->params->activate_action == ACTIVATE_ACTION_NONE))
-                {
-                    ev->value_mask &= ~(CWSibling | CWStackMode);
-                    TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window);
-                    FLAG_SET (c->flags, CLIENT_FLAG_DEMANDS_ATTENTION);
-                    clientSetNetState (c);
-                }
-                else
-                {
-                    clientActivate (c, getXServerTime (display_info));
-                }
-            }
-        }
-
-        clientConfigure (c, &wc, ev->value_mask, (constrained ? CFG_CONSTRAINED : 0) | CFG_REQUEST);
+        clientAdjustCoordGravity (c, c->gravity, &ev->value_mask, &wc);
+        clientMoveResizeWindow (c, &wc, ev->value_mask);
     }
     else
     {
@@ -1408,7 +1290,7 @@ handleConfigureRequest (DisplayInfo *display_info, XConfigureRequestEvent * ev)
 static eventFilterStatus
 handleEnterNotify (DisplayInfo *display_info, XCrossingEvent * ev)
 {
-    static Time lastresist = (Time) CurrentTime;
+    static guint32 lastresist = CurrentTime;
     ScreenInfo *screen_info;
     Client *c;
     int b;
@@ -1927,6 +1809,14 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
             c->user_time_win = getNetWMUserTimeWindow(display_info, c->window);
             clientAddUserTimeWin (c);
         }
+        else if (ev->atom == display_info->atoms[NET_WM_PID])
+        {
+            long pid;
+            TRACE ("client \"%s\" (0x%lx) has received a NET_WM_PID notify", c->name, c->window);
+            getHint (display_info, c->window, NET_WM_PID, (long *) &pid);
+            c->pid = (GPid) pid;
+            TRACE ("Client \"%s\" (0x%lx) updated PID = %i", c->name, c->window, c->pid);
+        }
         else if (ev->atom == display_info->atoms[NET_WM_WINDOW_OPACITY])
         {
             TRACE ("client \"%s\" (0x%lx) has received a NET_WM_OPACITY notify", c->name, c->window);
@@ -2015,7 +1905,6 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
     eventFilterStatus status;
     ScreenInfo *screen_info;
     Client *c;
-    gboolean is_transient;
 
     TRACE ("entering handleClientMessage");
 
@@ -2025,14 +1914,13 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
     {
         status = EVENT_FILTER_REMOVE;
         screen_info = c->screen_info;
-        is_transient = clientIsValidTransientOrModal (c);
 
         if ((ev->message_type == display_info->atoms[WM_CHANGE_STATE]) && (ev->format == 32) && (ev->data.l[0] == IconicState))
         {
             TRACE ("client \"%s\" (0x%lx) has received a WM_CHANGE_STATE event", c->name, c->window);
-            if (!FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED) && CLIENT_CAN_HIDE_WINDOW (c))
+            if (!FLAG_TEST (c->flags, CLIENT_FLAG_ICONIFIED))
             {
-                clientHide (c, c->win_workspace, TRUE);
+                clientWithdraw (c, c->win_workspace, TRUE);
             }
         }
         else if ((ev->message_type == display_info->atoms[WIN_STATE]) && (ev->format == 32))
@@ -2043,7 +1931,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         else if ((ev->message_type == display_info->atoms[WIN_LAYER]) && (ev->format == 32))
         {
             TRACE ("client \"%s\" (0x%lx) has received a WIN_LAYER event", c->name, c->window);
-            if ((ev->data.l[0] != c->win_layer) && !is_transient)
+            if (ev->data.l[0] != c->win_layer)
             {
                 clientSetLayer (c, ev->data.l[0]);
             }
@@ -2051,7 +1939,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         else if ((ev->message_type == display_info->atoms[WIN_WORKSPACE]) && (ev->format == 32))
         {
             TRACE ("client \"%s\" (0x%lx) has received a WIN_WORKSPACE event", c->name, c->window);
-            if ((ev->data.l[0] != c->win_workspace) && !is_transient)
+            if (ev->data.l[0] != c->win_workspace)
             {
                 clientSetWorkspace (c, ev->data.l[0], TRUE);
             }
@@ -2059,27 +1947,24 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
         else if ((ev->message_type == display_info->atoms[NET_WM_DESKTOP]) && (ev->format == 32))
         {
             TRACE ("client \"%s\" (0x%lx) has received a NET_WM_DESKTOP event", c->name, c->window);
-            if (!is_transient)
+            if (ev->data.l[0] == ALL_WORKSPACES)
             {
-                if (ev->data.l[0] == ALL_WORKSPACES)
+                if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_STICK) && !FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
                 {
-                    if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_STICK) && !FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
-                    {
-                        clientStick (c, TRUE);
-                        frameQueueDraw (c, FALSE);
-                    }
+                    clientStick (c, TRUE);
+                    frameQueueDraw (c, FALSE);
                 }
-                else
+            }
+            else
+            {
+                if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_STICK) && FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
                 {
-                    if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_STICK) && FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
-                    {
-                        clientUnstick (c, TRUE);
-                        frameQueueDraw (c, FALSE);
-                    }
-                    if (ev->data.l[0] != c->win_workspace)
-                    {
-                        clientSetWorkspace (c, ev->data.l[0], TRUE);
-                    }
+                    clientUnstick (c, TRUE);
+                    frameQueueDraw (c, FALSE);
+                }
+                if (ev->data.l[0] != c->win_workspace)
+                {
+                    clientSetWorkspace (c, ev->data.l[0], TRUE);
                 }
             }
         }
@@ -2098,20 +1983,25 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
             TRACE ("client \"%s\" (0x%lx) has received a NET_WM_MOVERESIZE event", c->name, c->window);
             clientNetMoveResize (c, ev);
         }
+        else if ((ev->message_type == display_info->atoms[NET_MOVERESIZE_WINDOW]) && (ev->format == 32))
+        {
+            TRACE ("client \"%s\" (0x%lx) has received a NET_MOVERESIZE_WINDOW event", c->name, c->window);
+            clientNetMoveResizeWindow (c, ev);
+        }
         else if ((ev->message_type == display_info->atoms[NET_ACTIVE_WINDOW]) && (ev->format == 32))
         {
             gboolean source_is_application;
-            Time ev_time;
+            guint32 ev_time;
 
-            ev_time = myDisplayGetTime (display_info, (Time) ev->data.l[1]);
+            ev_time = myDisplayGetTime (display_info, (guint32) ev->data.l[1]);
             source_is_application = (ev->data.l[0] == 1);
 
             TRACE ("client \"%s\" (0x%lx) has received a NET_ACTIVE_WINDOW event", c->name, c->window);
             if (source_is_application)
             {
-                Time current = myDisplayGetLastUserTime (display_info);
+                guint32 current = myDisplayGetLastUserTime (display_info);
 
-                TRACE ("Time of event received is %u, current XServer time is %u", (unsigned int) ev_time, (unsigned int) current);
+                TRACE ("Time of event received is %u, current XServer time is %u", (guint32) ev_time, (guint32) current);
                 if ((screen_info->params->prevent_focus_stealing) && TIMESTAMP_IS_BEFORE(ev_time, current))
                 {
                     TRACE ("Setting WM_STATE_DEMANDS_ATTENTION flag on \"%s\" (0x%lx)", c->name, c->window);
@@ -2153,7 +2043,7 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
                 (ev->data.l[0] != screen_info->current_ws))
             {
                 workspaceSwitch (screen_info, ev->data.l[0], NULL, TRUE,
-                                 myDisplayGetTime (display_info, (Time) ev->data.l[1]));
+                                 myDisplayGetTime (display_info, (guint32) ev->data.l[1]));
             }
         }
         else if (((ev->message_type == display_info->atoms[WIN_WORKSPACE_COUNT]) ||
@@ -2204,6 +2094,14 @@ handleClientMessage (DisplayInfo *display_info, XClientMessageEvent * ev)
                 display_info->quit = TRUE;
             }
         }
+        else if (ev->message_type == display_info->atoms[WM_PROTOCOLS])
+        {
+            if (ev->data.l[0] == display_info->atoms[NET_WM_PING])
+            {
+                TRACE ("root has received a NET_WM_PING (pong) event\n");
+                clientReceiveNetWMPong (screen_info, (guint32) ev->data.l[1]);
+            }
+        }
         else
         {
             TRACE ("unidentified client message for window 0x%lx", ev->window);
@@ -2293,27 +2191,9 @@ handleColormapNotify (DisplayInfo *display_info, XColormapEvent * ev)
 }
 
 static eventFilterStatus
-handleMappingNotify (DisplayInfo *display_info, XMappingEvent * ev)
+handleReparentNotify (DisplayInfo *display_info, XReparentEvent * ev)
 {
-    TRACE ("entering handleMappingNotify");
-
-    /* Refreshes the stored modifier and keymap information */
-    XRefreshKeyboardMapping (ev);
-
-    /* Update internal modifiers masks if necessary */
-    if (ev->request == MappingModifier)
-    {
-        TRACE ("handleMappingNotify: modifiers mapping has changed");
-        initModifiers (display_info->dpy);
-    }
-
-    /* Regrab all keys if the notify is for keyboard (ie not pointer) */
-    if (ev->request != MappingPointer)
-    {
-        TRACE ("handleMappingNotify: Reload settings");
-        reloadSettings (display_info, UPDATE_BUTTON_GRABS);
-    }
-
+    TRACE ("entering handleReparentNotify, 0x%lx reparented in 0x%lx", ev->window, ev->parent);
     return EVENT_FILTER_PASS;
 }
 
@@ -2412,8 +2292,8 @@ handleEvent (DisplayInfo *display_info, XEvent * ev)
         case ColormapNotify:
             handleColormapNotify (display_info, (XColormapEvent *) ev);
             break;
-        case MappingNotify:
-            status = handleMappingNotify (display_info, (XMappingEvent *) ev);
+        case ReparentNotify:
+            status = handleReparentNotify (display_info, (XReparentEvent *) ev);
             break;
         default:
             if ((display_info->have_shape) && (ev->type == display_info->shape_event_base))
@@ -2436,6 +2316,11 @@ handleEvent (DisplayInfo *display_info, XEvent * ev)
         }
         else if (display_info->quit)
         {
+            /*
+             * Qutting on purpose, update session manager so
+             * it does not restart the program immediately
+             */
+            client_session_set_restart_style(display_info->session, SESSION_RESTART_IF_RUNNING);
             gtk_main_quit ();
         }
     }
@@ -2499,7 +2384,7 @@ menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer
             case MENU_OP_MINIMIZE:
                 if (CLIENT_CAN_HIDE_WINDOW (c))
                 {
-                    clientHide (c, c->win_workspace, TRUE);
+                    clientWithdraw (c, c->win_workspace, TRUE);
                 }
                 break;
             case MENU_OP_MOVE:
@@ -2509,7 +2394,7 @@ menu_callback (Menu * menu, MenuOp op, Window xid, gpointer menu_data, gpointer
                 clientResize (c, CORNER_BOTTOM_RIGHT, NULL);
                 break;
             case MENU_OP_MINIMIZE_ALL:
-                clientHideAll (c, c->win_workspace);
+                clientWithdrawAll (c, c->win_workspace);
                 break;
             case MENU_OP_UNMINIMIZE:
                 clientShow (c, TRUE);
@@ -2572,6 +2457,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
     Menu *menu;
     MenuOp ops;
     MenuOp insensitive;
+    gboolean is_transient;
     gint x, y;
 
     TRACE ("entering show_window_menu");
@@ -2588,6 +2474,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
 
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
+    is_transient = clientIsValidTransientOrModal (c);
 
     x = px;
     y = py;
@@ -2644,7 +2531,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
         insensitive |= MENU_OP_DELETE;
     }
 
-    if (!CLIENT_CAN_STICK_WINDOW(c))
+    if (is_transient || !FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_STICK))
     {
         insensitive |= MENU_OP_STICK | MENU_OP_UNSTICK;
     }
@@ -2684,7 +2571,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
         ops |= MENU_OP_FULLSCREEN;
     }
 
-    if (clientIsTransientOrModal (c) || (c->type != WINDOW_NORMAL))
+    if (is_transient || (c->type != WINDOW_NORMAL))
     {
         insensitive |= MENU_OP_FULLSCREEN | MENU_OP_UNFULLSCREEN;
     }
@@ -2702,8 +2589,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
         ops |= MENU_OP_ABOVE | MENU_OP_BELOW;
     }
 
-    if (clientIsValidTransientOrModal (c) ||
-        FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
+    if (is_transient || FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
     {
         insensitive |= MENU_OP_NORMAL | MENU_OP_ABOVE | MENU_OP_BELOW;
     }
@@ -2715,7 +2601,7 @@ show_window_menu (Client *c, gint px, gint py, guint button, guint32 time)
         ops |= MENU_OP_CONTEXT_HELP;
     }
 
-    if (clientIsValidTransientOrModal (c)
+    if (is_transient
         || !FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_STICK)
         || FLAG_TEST (c->flags, CLIENT_FLAG_STICKY))
     {
