@@ -1,4 +1,4 @@
-/*      $Id: focus.h 28362 2008-10-22 19:58:39Z olivier $
+/*      $Id: focus.h 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,9 +12,11 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
 
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
@@ -22,7 +24,7 @@
 #define INC_FOCUS_H
 
 #ifdef HAVE_CONFIG_H
-#  include "config.h"
+#include "config.h"
 #endif
 
 #include <X11/X.h>
@@ -37,28 +39,29 @@
 #define FOCUS_IGNORE_MODAL              (1<<1)
 #define FOCUS_FORCE                     (1<<2)
 
-void                     clientFocusTop                         (ScreenInfo *, 
+void                     clientFocusTop                         (ScreenInfo *,
                                                                  int,
                                                                  guint32);
 gboolean                 clientFocusNew                         (Client *);
-gboolean                 clientSelectMask                       (Client *, 
-                                                                 int, 
+gboolean                 clientSelectMask                       (Client *,
+                                                                 int,
                                                                  int);
-Client                  *clientGetNext                          (Client *, 
+Client                  *clientGetNext                          (Client *,
                                                                  int);
-Client                  *clientGetPrevious                      (Client *, 
+Client                  *clientGetPrevious                      (Client *,
                                                                  int);
-void                     clientPassFocus                        (ScreenInfo *, 
-                                                                 Client *, 
-                                                                 Client *);
+void                     clientPassFocus                        (ScreenInfo *,
+                                                                 Client *,
+                                                                 GList *);
 gboolean                 clientAcceptFocus                      (Client *);
 void                     clientSortRing                         (Client *);
-void                     clientUpdateFocus                      (ScreenInfo *, 
-                                                                 Client *, 
+void                     clientSetLast                          (Client *);
+void                     clientUpdateFocus                      (ScreenInfo *,
+                                                                 Client *,
                                                                  unsigned short);
-void                     clientSetFocus                         (ScreenInfo *, 
-                                                                 Client *, 
-                                                                 guint32, 
+void                     clientSetFocus                         (ScreenInfo *,
+                                                                 Client *,
+                                                                 guint32,
                                                                  unsigned short);
 void                     clientInitFocusFlag                    (Client *);
 Client                  *clientGetFocus                         (void);
@@ -73,6 +76,8 @@ void                     clientUngrabMouseButtonForAll          (ScreenInfo *);
 void                     clientPassGrabMouseButton              (Client *);
 Client                  *clientGetLastUngrab                    (void);
 void                     clientClearLastUngrab                  (void);
-
+void                     clientClearDelayedFocus                (void);
+void                     clientAddDelayedFocus                  (Client *);
+Client                  *clientGetDelayedFocus                  (void);
 
 #endif /* INC_FOCUS_H */
