@@ -1,4 +1,4 @@
-/*      $Id: hints.c 27357 2008-07-21 09:14:12Z olivier $
+/*      $Id: hints.c 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -75,24 +75,6 @@ internal_utf8_strndup (const gchar *src, gssize max_len)
     return g_strndup (src, s - src);
 }
 
-static gchar*
-create_name_with_host (DisplayInfo *display_info, const gchar *name, const gchar *hostname)
-{
-    gchar *title;
-
-    if (strlen (hostname) && (display_info->hostname) && (g_strcasecmp (display_info->hostname, hostname)))
-    {
-        /* TRANSLATORS: "(on %s)" is like "running on" the name of the other host */
-        title = g_strdup_printf (_("%s (on %s)"), name, hostname);
-    }
-    else
-    {
-        title = g_strdup (name);
-    }
-
-    return title;
-}
-
 unsigned long
 getWMState (DisplayInfo *display_info, Window w)
 {
@@ -196,6 +178,11 @@ getWMProtocols (DisplayInfo *display_info, Window w)
             {
                 result |= WM_PROTOCOLS_CONTEXT_HELP;
             }
+            /* Ping */
+            if (*ap == display_info->atoms[NET_WM_PING])
+            {
+                result |= WM_PROTOCOLS_PING;
+            }
         }
         if (protocols)
         {
@@ -399,7 +386,7 @@ setGnomeProtocols (DisplayInfo *display_info, Window root, Window w)
 void
 setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
 {
-    Atom atoms[64];
+    Atom atoms[ATOM_COUNT];
     unsigned long data[1];
     int i;
 
@@ -414,26 +401,35 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
     atoms[i++] = display_info->atoms[NET_DESKTOP_NAMES];
     atoms[i++] = display_info->atoms[NET_DESKTOP_VIEWPORT];
     atoms[i++] = display_info->atoms[NET_FRAME_EXTENTS];
+    atoms[i++] = display_info->atoms[NET_MOVERESIZE_WINDOW];
     atoms[i++] = display_info->atoms[NET_NUMBER_OF_DESKTOPS];
     atoms[i++] = display_info->atoms[NET_REQUEST_FRAME_EXTENTS];
     atoms[i++] = display_info->atoms[NET_SHOWING_DESKTOP];
     atoms[i++] = display_info->atoms[NET_SUPPORTED];
     atoms[i++] = display_info->atoms[NET_SUPPORTING_WM_CHECK];
+    atoms[i++] = display_info->atoms[NET_SYSTEM_TRAY_OPCODE];
+    atoms[i++] = display_info->atoms[NET_WM_ACTION_ABOVE];
+    atoms[i++] = display_info->atoms[NET_WM_ACTION_BELOW];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_CHANGE_DESKTOP];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_CLOSE];
+    atoms[i++] = display_info->atoms[NET_WM_ACTION_FULLSCREEN];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_MAXIMIZE_HORZ];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_MAXIMIZE_VERT];
+    atoms[i++] = display_info->atoms[NET_WM_ACTION_MINIMIZE];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_MOVE];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_RESIZE];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_SHADE];
     atoms[i++] = display_info->atoms[NET_WM_ACTION_STICK];
     atoms[i++] = display_info->atoms[NET_WM_ALLOWED_ACTIONS];
+    atoms[i++] = display_info->atoms[NET_WM_CONTEXT_HELP];
     atoms[i++] = display_info->atoms[NET_WM_DESKTOP];
     atoms[i++] = display_info->atoms[NET_WM_ICON];
     atoms[i++] = display_info->atoms[NET_WM_ICON_GEOMETRY];
     atoms[i++] = display_info->atoms[NET_WM_ICON_NAME];
     atoms[i++] = display_info->atoms[NET_WM_MOVERESIZE];
     atoms[i++] = display_info->atoms[NET_WM_NAME];
+    atoms[i++] = display_info->atoms[NET_WM_PID];
+    atoms[i++] = display_info->atoms[NET_WM_PING];
     atoms[i++] = display_info->atoms[NET_WM_STATE];
     atoms[i++] = display_info->atoms[NET_WM_STATE_ABOVE];
     atoms[i++] = display_info->atoms[NET_WM_STATE_BELOW];
@@ -453,6 +449,8 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
     atoms[i++] = display_info->atoms[NET_WM_SYNC_REQUEST_COUNTER];
     atoms[i++] = display_info->atoms[NET_WM_USER_TIME];
     atoms[i++] = display_info->atoms[NET_WM_USER_TIME_WINDOW];
+    atoms[i++] = display_info->atoms[NET_WM_WINDOW_OPACITY];
+    atoms[i++] = display_info->atoms[NET_WM_WINDOW_OPACITY_LOCKED];
     atoms[i++] = display_info->atoms[NET_WM_WINDOW_TYPE];
     atoms[i++] = display_info->atoms[NET_WM_WINDOW_TYPE_DESKTOP];
     atoms[i++] = display_info->atoms[NET_WM_WINDOW_TYPE_DIALOG];
@@ -466,7 +464,10 @@ setNetSupportedHint (DisplayInfo *display_info, Window root, Window check_win)
 #ifdef HAVE_LIBSTARTUP_NOTIFICATION
     atoms[i++] = display_info->atoms[NET_STARTUP_ID];
 #endif
-    g_assert (i < 64);
+#ifdef ENABLE_KDE_SYSTRAY_PROXY
+    atoms[i++] = display_info->atoms[KDE_NET_WM_SYSTEM_TRAY_WINDOW_FOR];
+#endif
+    g_assert (i < ATOM_COUNT);
     data[0] = check_win;
     XChangeProperty (display_info->dpy, root, display_info->atoms[NET_SUPPORTED],
                      XA_ATOM, 32, PropModeReplace, (unsigned char *) atoms, i);
@@ -865,12 +866,12 @@ getWindowProp (DisplayInfo *display_info, Window window, int atom_id, Window *w)
 }
 
 gboolean
-getClientMachine (DisplayInfo *display_info, Window w, gchar **machine)
+getWindowHostname (DisplayInfo *display_info, Window w, gchar **machine)
 {
     char *str;
     gboolean status;
 
-    TRACE ("entering getClientMachine");
+    TRACE ("entering getWindowHostname");
 
     g_return_val_if_fail (machine != NULL, FALSE);
     *machine = NULL;
@@ -893,37 +894,31 @@ getClientMachine (DisplayInfo *display_info, Window w, gchar **machine)
 }
 
 gboolean
-getWindowName (DisplayInfo *display_info, Window w, gchar **title)
+getWindowName (DisplayInfo *display_info, Window w, gchar **name)
 {
     char *str;
     int len;
-    gchar *machine;
-    gchar *name;
     gboolean status;
 
     TRACE ("entering getWindowName");
 
-    g_return_val_if_fail (title != NULL, FALSE);
-    *title = NULL;
+    g_return_val_if_fail (name != NULL, FALSE);
+    *name = NULL;
     g_return_val_if_fail (w != None, FALSE);
 
     status = FALSE;
-    getClientMachine (display_info, w, &machine);
     if (getUTF8StringData (display_info, w, NET_WM_NAME, &str, &len) ||
         (str = get_text_property (display_info, w, XA_WM_NAME)))
     {
-        name = internal_utf8_strndup (str, MAX_STR_LENGTH);
-        *title = create_name_with_host (display_info, name, machine);
-        xfce_utf8_remove_controls(*title, -1, NULL);
-        g_free (name);
+        *name = internal_utf8_strndup (str, MAX_STR_LENGTH);
+        xfce_utf8_remove_controls(*name, -1, NULL);
         XFree (str);
         status = TRUE;
     }
     else
     {
-        *title = g_strdup ("");
+        *name = g_strdup ("");
     }
-    g_free (machine);
     return status;
 }
 
@@ -969,7 +964,7 @@ getClientLeader (DisplayInfo *display_info, Window window)
 }
 
 gboolean
-getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
+getNetWMUserTime (DisplayInfo *display_info, Window window, guint32 *time)
 {
     Atom actual_type;
     int actual_format;
@@ -988,12 +983,12 @@ getNetWMUserTime (DisplayInfo *display_info, Window window, Time *time)
         if ((data) && (actual_type == XA_CARDINAL)
             && (nitems == 1) && (bytes_after == 0))
         {
-            *time = *((long *) data);
+            *time = *((guint32 *) data);
             XFree (data);
             return TRUE;
         }
     }
-    *time = (Time) 0;
+    *time = 0;
 
     return FALSE;
 }
@@ -1165,7 +1160,7 @@ gboolean
 setXAtomManagerOwner (DisplayInfo *display_info, Atom atom, Window root, Window w)
 {
     XClientMessageEvent ev;
-    Time server_time;
+    guint32 server_time;
     int status;
 
     g_return_val_if_fail (root != None, FALSE);
@@ -1219,27 +1214,27 @@ updateXserverTime (DisplayInfo *display_info)
                      8, PropModeReplace, (unsigned char *) &c, 1);
 }
 
-Time
+guint32
 getXServerTime (DisplayInfo *display_info)
 {
     ScreenInfo *screen_info;
     XEvent xevent;
-    Time timestamp;
+    guint32 timestamp;
 
-    g_return_val_if_fail (display_info, (Time) CurrentTime);
+    g_return_val_if_fail (display_info, CurrentTime);
     timestamp = myDisplayGetCurrentTime (display_info);
-    if (timestamp == (Time) CurrentTime)
+    if (timestamp == CurrentTime)
     {
         screen_info = myDisplayGetDefaultScreen (display_info);
-        g_return_val_if_fail (screen_info,  (Time) CurrentTime);
+        g_return_val_if_fail (screen_info,  CurrentTime);
 
         TRACE ("getXServerTime: Using X server roundtrip");
         updateXserverTime (display_info);
         XWindowEvent (display_info->dpy, display_info->timestamp_win, PropertyChangeMask, &xevent);
-        timestamp = (Time) myDisplayUpdateCurrentTime (display_info, &xevent);
+        timestamp = myDisplayUpdateCurrentTime (display_info, &xevent);
     }
 
-    TRACE ("getXServerTime gives timestamp=%u", (unsigned int) timestamp);
+    TRACE ("getXServerTime gives timestamp=%u", (guint32) timestamp);
     return timestamp;
 }
 
