@@ -1,4 +1,4 @@
-/*      $Id: hints.h 27356 2008-07-20 21:22:15Z olivier $
+/*      $Id: hints.h 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -83,6 +83,7 @@
 #define WM_PROTOCOLS_TAKE_FOCUS                 (1L<<0)
 #define WM_PROTOCOLS_DELETE_WINDOW              (1L<<1)
 #define WM_PROTOCOLS_CONTEXT_HELP               (1L<<2)
+#define WM_PROTOCOLS_PING                       (1L<<3)
 
 #define WIN_LAYER_DESKTOP                       0
 #define WIN_LAYER_BELOW                         2
@@ -234,7 +235,7 @@ gboolean                 getWindowProp                          (DisplayInfo *,
                                                                  Window,
                                                                  int,
                                                                  Window *);
-gboolean                 getClientMachine                       (DisplayInfo *,
+gboolean                 getWindowHostname                      (DisplayInfo *,
                                                                  Window,
                                                                  gchar **);
 gboolean                 getWindowRole                          (DisplayInfo *,
@@ -242,9 +243,9 @@ gboolean                 getWindowRole                          (DisplayInfo *,
                                                                  gchar **);
 Window                   getClientLeader                        (DisplayInfo *,
                                                                  Window);
-gboolean                 getNetWMUserTime                       (DisplayInfo *,
-                                                                 Window,
-                                                                 Time *);
+gboolean                 getNetWMUserTime                       (DisplayInfo *, 
+                                                                 Window, 
+                                                                 guint32 *);
 Window                   getNetWMUserTimeWindow                 (DisplayInfo *,
                                                                  Window);
 gboolean                 getClientID                            (DisplayInfo *,
@@ -276,7 +277,7 @@ gboolean                 setAtomIdManagerOwner                  (DisplayInfo *,
                                                                  Window ,
                                                                  Window);
 void                     updateXserverTime                      (DisplayInfo *);
-Time                     getXServerTime                         (DisplayInfo *);
+guint32                  getXServerTime                         (DisplayInfo *);
 
 #ifdef ENABLE_KDE_SYSTRAY_PROXY
 gboolean                 checkKdeSystrayWindow                  (DisplayInfo *,
