@@ -1,4 +1,4 @@
-/*      $Id: keyboard.h 27421 2008-08-04 20:28:44Z olivier $
+/*      $Id: keyboard.h 28532 2008-10-31 14:51:13Z jannis $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@ struct _MyKey
 {
     KeyCode keycode;
     int modifier;
+    gchar *internal_name;
 };
 
 extern unsigned int AltMask;
@@ -44,7 +45,7 @@ extern unsigned int ScrollLockMask;
 extern unsigned int SuperMask;
 extern unsigned int HyperMask;
 
-int                      getModifierMap                         (const char *);
+guint                    getModifierMap                         (const char *);
 void                     parseKeyString                         (Display *,
                                                                  MyKey *,
                                                                  const char *);
