@@ -1,4 +1,4 @@
-/*      $Id: main.c 27421 2008-08-04 20:28:44Z olivier $
+/*      $Id: main.c 28517 2008-10-30 17:49:12Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -62,6 +62,7 @@
 #include "startup_notification.h"
 #include "compositor.h"
 #include "spinning_cursor.h"
+#include "stock_icons.h"
 
 #define BASE_EVENT_MASK \
     SubstructureNotifyMask|\
@@ -432,6 +433,7 @@ initialize (int argc, char **argv, gint compositor_mode, gboolean replace_wm)
 #else /* HAVE_COMPOSITOR */
     display_info->enable_compositor = FALSE;
 #endif /* HAVE_COMPOSITOR */
+    initWMStopIcons ();
 
     initModifiers (display_info->dpy);
 
