@@ -1,4 +1,4 @@
-/*      $Id: moveresize.c 27548 2008-08-24 16:00:22Z olivier $
+/*      $Id: moveresize.c 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -537,7 +537,7 @@ clientMoveEventFilter (XEvent * xevent, gpointer data)
     static int edge_scroll_x = 0;
     static int edge_scroll_y = 0;
     static gboolean toggled_maximize = FALSE;
-    static Time lastresist = (Time) 0;
+    static guint32 lastresist = 0;
     unsigned long configure_flags;
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
@@ -733,7 +733,7 @@ clientMoveEventFilter (XEvent * xevent, gpointer data)
                         }
                         warp_pointer = TRUE;
                     }
-                    lastresist = (Time) 0;
+                    lastresist = 0;
                 }
                 if (edge_scroll_y > screen_info->params->wrap_resistance)
                 {
@@ -756,7 +756,7 @@ clientMoveEventFilter (XEvent * xevent, gpointer data)
                         }
                         warp_pointer = TRUE;
                     }
-                    lastresist = (Time) 0;
+                    lastresist = 0;
                 }
 
                 if (warp_pointer)
@@ -901,6 +901,13 @@ clientMove (Client * c, XEvent * ev)
         return;
     }
 
+    if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED) &&
+        !FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED))
+    {
+        /* Partial maximization, clear it up */
+        clientRemoveMaximizeFlag (c);
+    }
+
     screen_info = c->screen_info;
     display_info = screen_info->display_info;
 
