@@ -1,4 +1,4 @@
-/*      $Id: mywindow.c 23128 2006-09-11 20:39:40Z olivier $
+/*      $Id: mywindow.c 26999 2008-05-31 14:35:42Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,14 +12,16 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
 
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <X11/Xlib.h>
@@ -77,14 +79,27 @@ xfwmWindowInit (xfwmWindow * win)
 
 void
 xfwmWindowCreate (ScreenInfo * screen_info, Visual *visual, gint depth, Window parent,
-                  xfwmWindow * win, Cursor cursor)
+                  xfwmWindow * win, long eventmask, Cursor cursor)
 {
+    XSetWindowAttributes attributes;
+    unsigned long valuemask;
+
     TRACE ("entering xfwmWindowCreate");
 
     g_return_if_fail (screen_info != NULL);
 
-    win->window = XCreateSimpleWindow (myScreenGetXDisplay (screen_info),
-                                       parent, 0, 0, 1, 1, 0, 0, 0);
+    attributes.event_mask = eventmask;
+    valuemask = 0L;
+    if (eventmask != NoEventMask)
+    {
+        valuemask |= CWEventMask;
+    }
+
+    win->window = XCreateWindow (myScreenGetXDisplay (screen_info),
+                                 parent, 0, 0, 1, 1, 0, 0,
+                                 InputOutput, CopyFromParent,
+                                 valuemask, &attributes);
+
     TRACE ("Created XID 0x%lx", win->window);
     if (cursor != None)
     {
@@ -199,7 +214,7 @@ xfwmWindowVisible (xfwmWindow *win)
     g_return_val_if_fail (win, FALSE);
 
     return win->map;
-} 
+}
 
 gboolean
 xfwmWindowDeleted (xfwmWindow *win)
@@ -207,7 +222,7 @@ xfwmWindowDeleted (xfwmWindow *win)
     g_return_val_if_fail (win, TRUE);
 
     return (win->window == None);
-} 
+}
 
 void
 xfwmWindowTemp (ScreenInfo *screen_info, Visual *visual,
@@ -226,7 +241,6 @@ xfwmWindowTemp (ScreenInfo *screen_info, Visual *visual,
                                  InputOnly, CopyFromParent,
                                  CWEventMask | CWOverrideRedirect,
                                  &attributes);
-    XMapWindow (myScreenGetXDisplay (screen_info), win->window);
     if (bottom)
     {
         XLowerWindow (myScreenGetXDisplay (screen_info), win->window);
@@ -235,6 +249,7 @@ xfwmWindowTemp (ScreenInfo *screen_info, Visual *visual,
     {
         XRaiseWindow (myScreenGetXDisplay (screen_info), win->window);
     }
+    XMapWindow (myScreenGetXDisplay (screen_info), win->window);
     XFlush (myScreenGetXDisplay (screen_info));
 
     win->map = TRUE;
