@@ -1,4 +1,4 @@
-/*      $Id: netwm.c 27995 2008-09-30 16:37:35Z olivier $
+/*      $Id: netwm.c 28365 2008-10-22 20:10:00Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -268,7 +268,10 @@ clientGetNetState (Client * c)
             }
             else
             {
-                g_warning ("Unmanaged net_wm_state (window 0x%lx)", c->window);
+                gchar *atom_name;
+                atom_name = get_atom_name (display_info, atoms[i]);
+                g_warning ("Unmanaged net_wm_state (window 0x%lx, atom \"%s\")", c->window, atom_name);
+                g_free (atom_name);
             }
 
             ++i;
@@ -609,7 +612,7 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
     event->xbutton.button = button;
     event->xbutton.x_root = event->xkey.x_root = x_root;
     event->xbutton.y_root = event->xkey.y_root = y_root;
-    event->xbutton.time = event->xkey.time = myDisplayGetCurrentTime (display_info);
+    event->xbutton.time = event->xkey.time = (Time) myDisplayGetCurrentTime (display_info);
 
     switch (action)
     {
@@ -687,6 +690,39 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
     }
 }
 
+void
+clientNetMoveResizeWindow (Client * c, XClientMessageEvent * ev)
+{
+    XWindowChanges wc;
+    unsigned long mask;
+    int gravity;
+
+    g_return_if_fail (c != NULL);
+    TRACE ("entering clientNetMoveResizeWindow");
+    TRACE ("client \"%s\" (0x%lx)", c->name, c->window);
+
+    if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_MOVING_RESIZING))
+    {
+        /* not allowed */
+        return;
+    }
+
+    gravity = (ev->data.l[0] & 0xff);
+    if (!gravity)
+    {
+        gravity = c->gravity;
+    }
+
+    wc.x = ev->data.l[1];
+    wc.y = ev->data.l[2];
+    wc.width = ev->data.l[3];
+    wc.height = ev->data.l[4];
+    mask = (ev->data.l[0] & 0xf00) >> 8;
+
+    clientAdjustCoordGravity (c, gravity, &mask, &wc);
+    clientMoveResizeWindow (c, &wc, mask);
+}
+
 void
 clientUpdateFullscreenState (Client * c)
 {
@@ -1337,7 +1373,7 @@ clientUpdateLayerState (Client * c)
 }
 
 void
-clientSetNetActiveWindow (ScreenInfo *screen_info, Client *c, Time timestamp)
+clientSetNetActiveWindow (ScreenInfo *screen_info, Client *c, guint32 timestamp)
 {
     DisplayInfo *display_info;
     unsigned long data[2];
@@ -1389,7 +1425,7 @@ clientRemoveNetWMPing (Client *c)
 }
 
 void
-clientReceiveNetWMPong (ScreenInfo *screen_info, Time timestamp)
+clientReceiveNetWMPong (ScreenInfo *screen_info, guint32 timestamp)
 {
     Client *c;
     int i;
@@ -1409,7 +1445,7 @@ clientReceiveNetWMPong (ScreenInfo *screen_info, Time timestamp)
 }
 
 gboolean
-clientSendNetWMPing (Client *c, Time timestamp)
+clientSendNetWMPing (Client *c, guint32 timestamp)
 {
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
