@@ -1,4 +1,4 @@
-/*      $Id: spinning_cursor.h 23704 2006-11-04 22:36:42Z olivier $
+/*      $Id: spinning_cursor.h 26999 2008-05-31 14:35:42Z olivier $
 
         This program is free software; you can redistribute it and/or modify
         it under the terms of the GNU General Public License as published by
@@ -12,20 +12,22 @@
 
         You should have received a copy of the GNU General Public License
         along with this program; if not, write to the Free Software
-        Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+        Foundation, Inc., Inc., 51 Franklin Street, Fifth Floor, Boston,
+        MA 02110-1301, USA.
+
 
         mozilla  - (c) 1998 mozilla.org
-        xfwm4    - (c) 2002-2006 Olivier Fourdan
+        xfwm4    - (c) 2002-2008 Olivier Fourdan
 
  */
 
-#ifdef HAVE_CONFIG_H
-#  include "config.h"
-#endif
-
 #ifndef INC_SPINNING_CURSOR_H
 #define INC_SPINNING_CURSOR_H
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <X11/Xlib.h>
 
 Cursor                   cursorCreateSpinning                   (Display *);
